@@ -93,12 +93,12 @@ test_that("vis_clustered_graphs() works when all btw. group density is 0", {
   
   graphs <- clustered_graphs(object = mpf, clust.groups = "country")
   
-  graphs[[1]] |> 
-    tidygraph::as_tbl_graph() |> 
-    activate(edges) |> 
-    mutate(grp.density = c(0, 0, 0)) |> 
-    tidygraph::as.igraph() |> 
-    list() |> 
+  graphs[[1]] %>% 
+    tidygraph::as_tbl_graph() %>% 
+    activate(edges) %>% 
+    mutate(grp.density = c(0, 0, 0)) %>% 
+    tidygraph::as.igraph() %>% 
+    list() %>% 
     vis_clustered_graphs(edge.width.multiplier = 5,
            normalise.node.sizes = TRUE)
 })
@@ -109,11 +109,11 @@ test_that("vis_clustered_graphs() works when ???", {
   
   graphs <- clustered_graphs(object = mpf, clust.groups = "country")
   graphs <- 
-    graphs[[1]] |> 
-    tidygraph::as_tbl_graph() |> 
-    activate(edges) |> 
-    filter(FALSE) |> 
-    tidygraph::as.igraph() |> 
+    graphs[[1]] %>% 
+    tidygraph::as_tbl_graph() %>% 
+    activate(edges) %>% 
+    filter(FALSE) %>% 
+    tidygraph::as.igraph() %>% 
     list() 
     vis_clustered_graphs(graphs,
                          edge.width.multiplier = 5,
@@ -139,4 +139,4 @@ test_that("vis_clustered_graphs() works when ???", {
     ), alpha = 0.7)
 })
 
-}
\ No newline at end of file
+}
